@@ -21,7 +21,7 @@ from visualqc.image_utils import rescale_without_outliers
 from visualqc.interfaces import BaseReviewInterface
 from visualqc.utils import (check_inputs_defacing, check_out_dir,
                             compute_cell_extents_grid, pixdim_nifti_header,
-                            read_image, slice_aspect_ratio)
+                            read_image, slice_aspect_ratio, check_event_in_axes)
 from visualqc.workflows import BaseWorkflowVisualQC
 
 
@@ -61,7 +61,7 @@ class DefacingInterface(BaseReviewInterface):
         # include all the non-data axes here (so they wont be zoomed-in)
         self.unzoomable_axes = [self.checkbox.ax, self.text_box.ax,
                                 self.bt_next.ax, self.bt_quit.ax,
-                                self.radio_bt_vis_type]
+                                self.radio_bt_vis_type.ax]
 
         # this list of artists to be populated later
         # makes to handy to clean them all
@@ -193,7 +193,7 @@ class DefacingInterface(BaseReviewInterface):
 
 
     def reset_figure(self):
-        "Resets the figure to prepare it for display of next subject."
+        """Resets the figure to prepare it for display of next subject."""
 
         self.clear_data()
         self.clear_checkboxes()
@@ -236,7 +236,7 @@ class DefacingInterface(BaseReviewInterface):
         """Callback for mouse events."""
 
         if self.prev_axis is not None:
-            if event.inaxes not in self.unzoomable_axes:
+            if not check_event_in_axes(event, self.unzoomable_axes):
                 self.prev_axis.set_position(self.prev_ax_pos)
                 self.prev_axis.set_zorder(0)
                 self.prev_axis.patch.set_alpha(0.5)
@@ -244,8 +244,8 @@ class DefacingInterface(BaseReviewInterface):
 
         # right or double click to zoom in to any axis
         if (event.button in [3] or event.dblclick) and \
-            (event.inaxes is not None) and \
-            event.inaxes not in self.unzoomable_axes:
+                (event.inaxes is not None) and \
+                (not check_event_in_axes(event, self.unzoomable_axes)):
             self.prev_ax_pos = event.inaxes.get_position()
             event.inaxes.set_position(cfg.zoomed_position)
             event.inaxes.set_zorder(1)  # bring forth
@@ -276,11 +276,11 @@ class DefacingInterface(BaseReviewInterface):
             # notice parentheses at the end
             self.map_key_to_callback[key_pressed]()
         else:
-            if key_pressed in cfg.abbreviation_t1_mri_default_issue_list:
-                checked_label = cfg.abbreviation_t1_mri_default_issue_list[
+            if key_pressed in cfg.abbreviation_defacing_default_issue_list:
+                checked_label = cfg.abbreviation_defacing_default_issue_list[
                     key_pressed]
                 self.checkbox.set_active(
-                    cfg.t1_mri_default_issue_list.index(checked_label))
+                    cfg.defacing_default_issue_list.index(checked_label))
             else:
                 pass
 
@@ -288,7 +288,7 @@ class DefacingInterface(BaseReviewInterface):
 
 
 class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
-    """Rating worklfow for defaced MRI scans"""
+    """Rating workflow for defaced MRI scans"""
 
 
     def __init__(self,
@@ -386,13 +386,11 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
                                'alt+m': self.show_mixed,
                                'm+alt': self.show_mixed,
                                }
-        self.UI = DefacingInterface(self.collage.fig,
-                                    self.collage.flat_grid,
-                                    self.issue_list,
-                                    next_button_callback=self.next,
-                                    quit_button_callback=self.quit,
-                                    processing_choice_callback=self.process_and_display,
-                                    map_key_to_callback=map_key_to_callback)
+        self.UI = DefacingInterface(
+            self.collage.fig, self.collage.flat_grid, self.issue_list,
+            next_button_callback=self.next, quit_button_callback=self.quit,
+            processing_choice_callback=self.process_and_display,
+            map_key_to_callback=map_key_to_callback)
 
         # connecting callbacks
         self.con_id_click = self.fig.canvas.mpl_connect('button_press_event',
@@ -426,7 +424,7 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
             raise ValueError(
                 'pixel dimensions for the original and defaced images do not match! '
                 'They are: {}, {}'.format(
-                self.current_pixdim, self.pixdim_nifti_header(self.defaced_hdr)))
+                    self.current_pixdim, pixdim_nifti_header(self.defaced_hdr)))
 
         self.render_img_list = list()
         for rimg_path in self.images_for_id[unit_id]['render']:
@@ -448,7 +446,7 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
 
         skip_subject = False
         if np.count_nonzero(self.defaced_img) == 0 or \
-            np.count_nonzero(self.orig_img) == 0:
+                np.count_nonzero(self.orig_img) == 0:
             skip_subject = True
             print('Defaced or original MR image is empty!')
 
@@ -523,7 +521,7 @@ class RatingWorkflowDefacing(BaseWorkflowVisualQC, ABC):
 
         ax_counter = 0
         for dim, slice_num, (defaced, orig) in self.slice_picker.get_slices_multi(
-            [self.defaced_img, self.orig_img], extended=True):
+                [self.defaced_img, self.orig_img], extended=True):
 
             ax = self.collage.flat_grid[ax_counter]
             if vis_type in ('mixed',):
