@@ -20,11 +20,11 @@ from mrivis.utils import crop_image
 from visualqc import config as cfg
 from visualqc.image_utils import mask_image
 from visualqc.interfaces import BaseReviewInterface
-from visualqc.utils import (check_finite_int, check_id_list, check_input_dir_T1,
-                            check_out_dir, check_outlier_params, check_views,
-                            read_image, saturate_brighter_intensities, scale_0to1,
-                            check_bids_dir)
 from visualqc.readers import find_anatomical_images_in_BIDS
+from visualqc.utils import (check_bids_dir, check_finite_int, check_id_list,
+                            check_input_dir_T1, check_out_dir, check_outlier_params,
+                            check_views, read_image, saturate_brighter_intensities,
+                            scale_0to1)
 from visualqc.workflows import BaseWorkflowVisualQC
 
 # each rating is a set of labels, join them with a plus delimiter
@@ -514,10 +514,6 @@ class RatingWorkflowT1(BaseWorkflowVisualQC, ABC):
             skip_subject = True
             print('MR image is empty!')
 
-        # # where to save the visualization to
-        # out_vis_path = pjoin(self.out_dir, 'visual_qc_{}_{}'.format(
-        # self.vis_type, unit_id))
-
         return skip_subject
 
 
